@@ -8,7 +8,7 @@ use base 'DateTime';
 use Role::Tiny::With;
 use namespace::autoclean;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 with 'DateTimeX::Role::Immutable';
 
@@ -27,7 +27,9 @@ DateTimeX::Immutable - An immutable subclass of DateTime
 
 =head1 VERSION
 
-version 0.35
+version 0.36
+
+=for html <img src="https://travis-ci.org/mvgrimes/DateTimeX-Immutable.svg?branch=master" alt="Build Status">
 
 =head1 SYNOPSIS
 
@@ -90,11 +92,28 @@ At the moment, C<set_time_zone>, C<set_locale>, and C<set_formatter> continue
 to act as mutators. DateTime uses these internally and changing them creates
 unexpected behavior. These methods also do not really change the time value.
 
-TODO: Talk about why this is a good idea, how it is implemented, and how this
-differs from alternate approaches.
-
 See L<DateTime> for the rest of the documentation.
 
+=head1 WHY
+
+Reasons why this module eixsts:
+
+=over 4
+
+=item Mutability is bad!
+
+=item DateTime::Moonpig: Great idea but changes too much. We still want to be to truncate,
+set_*, etc, we just want the result returned. Changing the math goes beyond
+the scope of our needs. No integration with DBIC.
+
+=item Time::Moment: Excellent, but for code that already uses DateTime we want
+to continue. Also, Time::Moment's plugin for DBIC doesn't support native db
+date formats.
+
+=back
+
+(TODO: Expand on explanation for this module's existence.)
+
 =head1 SEE ALSO
 
 L<DateTime>, L<DateTime::Moonpig>, L<Time::Moment>
@@ -105,7 +124,7 @@ Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2015 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
