@@ -10,7 +10,7 @@ use Sub::Install;
 use DateTime;
 use namespace::autoclean;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 my %mutators = (
     add_duration      => 'plus_duration',
@@ -48,6 +48,24 @@ while ( my ( $orig_method, $new_method ) = each %mutators ) {
         } );
 }
 
+# Methods that return a duration, but mutate during processing
+for my $method (
+    qw(delta_md delta_days delta_ms subtract_datetime subtract_datetime_absolute)
+  )
+{
+    Sub::Install::install_sub( {
+            code => sub {
+                my $dt1 = DateTime->from_object( object => shift );
+                my $dt2 = DateTime->from_object( object => shift );
+                return $dt1->$method( $dt2, @_ );
+            },
+            as => $method,
+        } );
+}
+
+# Need to replace today, as the DateTime
+sub today { shift->now(@_)->trunc( to => 'day' ) }
+
 1;
 
 __END__
@@ -60,7 +78,7 @@ DateTimeX::Role::Immutable - A role that can be composed into a DateTime subclas
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -112,6 +130,8 @@ At the moment, C<set_time_zone>, C<set_locale>, and C<set_formatter> continue
 to act as mutators. DateTime uses these internally and changing them creates
 unexpected behavior. These methods also do not really change the time value.
 
+See L<DateTime> for the rest of the documentation.
+
 =head1 SEE ALSO
 
 L<DateTimeX::Role::Immutable>, L<DateTime>, L<DateTime::Moonpig>,
@@ -123,7 +143,7 @@ Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2015 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
